<template>
  <div :class="className" :style="{ height: height, width: width }" />
</template>

<script>
import echarts from 'echarts'
require('echarts/theme/macarons') // echarts theme
import resize from './mixins/resize'

// const animationDuration = 6000

export default {
  mixins: [resize],
  props: {
    className: {
      type: String,
      default: 'chart'
    },
    width: {
      type: String,
      default: '100%'
    },
    height: {
      type: String,
      default: '700px'
    },
    autoResize: {
      type: Boolean,
      default: true
    },
    chartData: {
      type: Object,
      required: true
    }
  },
  data() {
    return {
      chart: null
    }
  },
  watch: {
    chartData: {
      deep: true,
      handler(val) {
        this.setOptions(val)
      }
    }
  },
  mounted() {
    this.$nextTick(() => {
      this.initChart()
    })
  },
  beforeDestroy() {
    if (!this.chart) {
      return
    }
    this.chart.dispose()
    this.chart = null
  },
  methods: {
    initChart() {
      this.chart = echarts.init(this.$el, 'macarons')
      this.setOptions(this.chartData)
    },
    setOptions({ edmm, hdmm, ndmm, tagid, winmin, winmax } = {}) {
      console.log(0 - winmin * 10);
      console.log(winmax * 10);
      if (winmax * 10 == 0) {
        winmax = null
      } else {
        winmax = winmax * 10
      }
      if (0 - winmin * 10 == 0) {
        winmin = null
      } else {
        winmin = 0 - winmin * 10
      }
      // initChart() {
      // this.chart = echarts.init(this.$el, 'macarons')

      this.chart.setOption({
        tooltip: {
          trigger: 'axis',
          axisPointer: {
            type: 'shadow'
          }
        },
        legend: {
          data: ['东位移', '北位移', '天位移'],
          textStyle: {
            color: '#1890ff' // 标题文字颜色
          }
        },
        grid: {
          left: '3%',
          right: '4%',
          bottom: '3%',
          containLabel: true
        },

        xAxis: {
          //  data:tagid,
          max: winmax,
          min: winmin,
          boundaryGap: false,
          type: 'value',
          splitLine:false
        },
        yAxis: {
          data: tagid,
          type: 'category',
          //     axisTick: {
          //   show: false
          // },
          // max: function (value) {
          //   return value.max + 30
          // },
          // min: function (value) {
          //   return value.min - 30
          // },
          name: '/毫米',
        
        },
        series: [
          {
            name: '东位移',
            type: 'bar',
            // stack: 'Total',
            label: {
              show: true,
              // position: 'inside'
            },
            emphasis: {

              focus: 'series'
            },
            data: edmm
          },
          {
            name: '北位移',
            type: 'bar',
            // stack: 'Total',
            label: {
              show: true
            },
            emphasis: {
              focus: 'series'
            },
            data: ndmm
          },
          {
            name: '天位移',
            type: 'bar',
            // stack: 'Total',
            label: {
              show: true,
              // position: 'left'
            },
            emphasis: {
              focus: 'series'
            },
            data: hdmm
          }
        ]
      })
    }
  }
}
</script>
